@@ -242,14 +242,13 @@ const DocCommon = new Lang.Class({
         this.collection = false;
         this._collectionIconWatcher = null;
 
-        this.thumbnailed = false;
         this._thumbPath = null;
 
         this.populateFromCursor(cursor);
 
         this._refreshIconId =
-            Application.settings.connect('changed::view-as',
-                                         Lang.bind(this, this.refreshIcon));
+            Application.application.connect('action-state-changed::view-as',
+                                            Lang.bind(this, this.refreshIcon));
         this._filterId =
             Application.searchCategoryManager.connect('active-changed',
                                                       Lang.bind(this, this.refreshIcon));
@@ -397,7 +396,6 @@ const DocCommon = new Lang.Class({
         if (this._thumbPath) {
             this._refreshThumbPath();
         } else {
-            this.thumbnailed = false;
             this.createThumbnail(Lang.bind(this, this._onCreateThumbnail));
         }
     },
@@ -445,17 +443,22 @@ const DocCommon = new Lang.Class({
                             function(object, res) {
                                 try {
                                     let pixbuf = GdkPixbuf.Pixbuf.new_from_stream_finish(res);
-                                    this.thumbnailed = true;
                                     this._setOrigPixbuf(pixbuf);
                                 } catch (e) {
+                                    log('Unable to create pixbuf from ' + thumbFile.get_uri() + ': ' + e.toString());
                                     this._failedThumbnailing = true;
+                                    this._thumbPath = null;
+                                    thumbFile.delete_async(GLib.PRIORITY_DEFAULT, null, null);
                                 }
 
                                 // close the underlying stream immediately
                                 stream.close_async(0, null, null);
                             }));
                 } catch (e) {
+                    log('Unable to read file at ' + thumbFile.get_uri() + ': ' + e.toString());
                     this._failedThumbnailing = true;
+                    this._thumbPath = null;
+                    thumbFile.delete_async(GLib.PRIORITY_DEFAULT, null, null);
                 }
             }));
     },
@@ -523,7 +526,7 @@ const DocCommon = new Lang.Class({
 
         let thumbnailedPixbuf = null;
 
-        if (this.thumbnailed) {
+        if (this._thumbPath) {
             let [ slice, border ] = Utils.getThumbnailFrameBorder();
             thumbnailedPixbuf = Gd.embed_image_in_frame(emblemedPixbuf,
                 'resource:///org/gnome/documents/thumbnail-frame.png',
